<?php
namespace FiloBlu\Eva\Block\Widget;

use Magento\CatalogWidget\Block\Product\ProductsList;

class ProductSlider extends \Magento\Framework\View\Element\Template implements \Magento\Widget\Block\BlockInterface
{

    protected $_categoryRepository;
    protected $_filterProvider;
    protected $_resourceModelProduct;
    protected $_productRepository;
    protected $_cmsPageHelper;
    protected $_pageFactory;
    protected $categoryFactory;
    protected $_template = "widget/category-slider.phtml";

    public function __construct(
        \Magento\Framework\View\Element\Template\Context $context,
        \Magento\Catalog\Model\CategoryFactory $categoryFactory,
        \Magento\Catalog\Model\CategoryRepository $categoryRepository,
        \Magento\Cms\Model\Template\FilterProvider $filterProvider,
        \Magento\Catalog\Model\ResourceModel\Product $resourceModelProduct,
        \Magento\Catalog\Model\ProductRepository $productRepository,
        \Magento\Cms\Helper\Page $cmsPageHelper,
        \Magento\Cms\Model\PageFactory $pageFactory
    ) {
        $this->categoryFactory = $categoryFactory;
        parent::__construct($context);
        $this->_categoryRepository = $categoryRepository;
        $this->_filterProvider = $filterProvider;
        $this->_resourceModelProduct = $resourceModelProduct;
        $this->_productRepository = $productRepository;
        $this->_cmsPageHelper = $cmsPageHelper;
        $this->_pageFactory = $pageFactory;
    }

    public function getProductCollection()
    {
        $productCollection = null;
        $maxCollectionItem = 4;

        if (count($this->getMaxitems())) {
            $maxCollectionItem = $this->getMaxitems();
        };

        $idPathCatalog = $this->getCategory();

        $idPath = explode('/', $idPathCatalog);

        if (isset($idPath[0]) && isset($idPath[1]) && $idPath[0] == 'category') {
            $categoryId = $idPath[1];
            if ($categoryId) {
                $productCollection = $this->categoryFactory->create()->load($categoryId)->getProductCollection()->addAttributeToSelect(['sku','name'])->setOrder('cat_index_position','ASC')->setPageSize($maxCollectionItem);
            }
        }

        return $productCollection;
    }

    public function getCategoryImage()
    {
        $idPathCatalog = $this->getCategory();
        $idPath = explode('/', $idPathCatalog);
        $categoryId = $idPath[1];
        $category = $this->categoryFactory->create()->load($categoryId);
        $categoryImageUrl = $category->getImageUrl();

        return $categoryImageUrl;
    }

    public function getFilteredContent($string) {
        return $this->_filterProvider->getBlockFilter()->setStoreId($this->_storeManager->getStore()->getId())->filter($string);
    }

    public function getCategoryUrlById($categoryId) {
        return ( $categoryId ) ? $this->_categoryRepository->get($categoryId)->getUrl() : null;
    }

    public function getProductUrlById($productId)
    {
        $product = $this->_productRepository->getById($productId);
        return $product->getUrlModel()->getUrl($product);
    }

    public function getCmsPageUrl($pageId) {
        return $this->_cmsPageHelper->getPageUrl($pageId);
    }

    public function getWidgetUrl() {
        $_url = null;
        $linkType = $this->getLinkType();
        $customUri = $this->getLinkCustom();
        $categoryId = str_replace('category/','',$this->getLinkCategory());
        $productId = str_replace('product/','',$this->getLinkProduct());
        $pageId = $this->getLinkCmspage();

        switch ($linkType) {
            case 'default':
            case 1:
                $_url = '';
                break;

            case 2:
                $_url = $this->getCategoryUrlById($categoryId);
                break;

            case 3:
                $_url = $this->getProductUrlById($productId);
                break;

            case 4:
                $_url = $this->getCmsPageUrl($pageId);
                break;

            case 5:
                $_url = $this->getFilteredContent($customUri);
                break;
        }

        return trim($_url);
    }

    public function getCategoryTitle($categoryId) {
        return ( $categoryId ) ? $this->_categoryRepository->get($categoryId)->getName() : null;
    }

    public function getProductName($productId)
    {
        $product = $this->_productRepository->getById($productId);
        return $product->getName();
    }

    public function getCmsPageTitle($pageId) {
        return $this->_pageFactory->create()->load($pageId)->getTitle();
    }
}